@@ -1,5 +1,5 @@
 from pypylon import pylon
-from Camera import Camera
+from GhostScan.Camera import Camera
 from abc import ABC
 import numpy as np
 import cv2
