@@ -1,6 +1,6 @@
 import numpy as np
 import cv2
-from Camera, import Camera
+from GhostScan.Camera, import Camera
 import time
 import matplotlib.pyplot as plt
 import sys
